Welcome to ClientVPS Mirrors

Help for package dictionaRy
Type: Package
Title: Retrieve the Dictionary Definitions of English Words
Version: 0.1.1
Depends: jsonlite, tibble
Maintainer: Steve Condylios <steve.condylios@gmail.com>
BugReports: https://github.com/stevecondylios/dictionaRy/issues
URL: https://github.com/stevecondylios/dictionaRy
Description: An R interface to the 'Free Dictionary API' https://dictionaryapi.dev/, https://github.com/meetDeveloper/freeDictionaryAPI. Retrieve dictionary definitions for English words, as well as additional information including phonetics, part of speech, origins, audio pronunciation, example usage, synonyms and antonyms, returned in 'tidy' format for ease of use.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.1.2
NeedsCompilation: no
Packaged: 2022-01-08 05:00:29 UTC; st
Author: Steve Condylios ORCID iD [aut, cre], Zane Dax [ctb]
Repository: CRAN
Date/Publication: 2022-01-10 17:52:47 UTC

Retrieve the dictionary definition of an English word

Description

Retrieve the dictionary definition of an English word

Usage

define(word)

Arguments

word

The word you wish to define

Value

A tibble with a row for each unique combination of word, meaning, part of speech, and definition. And a column for:

Examples

## Not run: 
  # Get the definition of "hello"
  define("hello") # Returns a 3 row data.frame

  # Homonyms (words with >1 meaning)
  define("bark") # Returns a 9 row data.frame

  # Unknown words will return a 0 row data.frame and message
  define("sdfsdfsdfsdfsdf")
  # No definition found for sdfsdfsdfsdfsdf


## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.